@@ -1,5 +1,8 @@
 # flake8: NOQA: E501
 """Sphinx configuration for libtmux."""
+
+from __future__ import annotations
+
 import contextlib
 import inspect
 import pathlib
@@ -21,7 +24,7 @@ sys.path.insert(0, str(project_src))
 sys.path.insert(0, str(cwd / "_ext"))
 
 # package data
-about: t.Dict[str, str] = {}
+about: dict[str, str] = {}
 with (project_src / "libtmux" / "__about__.py").open() as fp:
     exec(fp.read(), about)
 
@@ -45,6 +48,7 @@ myst_enable_extensions = [
     "substitution",
     "replacements",
     "strikethrough",
+    "linkify",
 ]
 
 templates_path = ["_templates"]
@@ -56,8 +60,8 @@ master_doc = "index"
 project = about["__title__"]
 project_copyright = about["__copyright__"]
 
-version = "%s" % (".".join(about["__version__"].split("."))[:2])
-release = "%s" % (about["__version__"])
+version = "{}".format(".".join(about["__version__"].split("."))[:2])
+release = "{}".format(about["__version__"])
 
 exclude_patterns = ["_build"]
 
@@ -69,8 +73,8 @@ html_static_path = ["_static"]
 html_css_files = ["css/custom.css"]
 html_extra_path = ["manifest.json"]
 html_theme = "furo"
-html_theme_path: t.List[str] = []
-html_theme_options: t.Dict[str, t.Union[str, t.List[t.Dict[str, str]]]] = {
+html_theme_path: list[str] = []
+html_theme_options: dict[str, str | list[dict[str, str]]] = {
     "light_logo": "img/libtmux.svg",
     "dark_logo": "img/libtmux.svg",
     "footer_icons": [
@@ -88,7 +92,7 @@ html_theme_options: t.Dict[str, t.Union[str, t.List[t.Dict[str, str]]]] = {
     "source_repository": f"{about['__github__']}/",
     "source_branch": "master",
     "source_directory": "docs/",
-    "announcement": "<em>Friendly reminder:</em> 📌 Pin the package, libtmux is pre-1.0 and APIs will be <a href='/migration.html'>changing</a> throughout 2022-2024.",
+    "announcement": "<em>Friendly reminder:</em> 📌 Pin the package, libtmux is pre-1.0 and APIs will be <a href='/migration.html'>changing</a> throughout 2026.",
 }
 html_sidebars = {
     "**": [
@@ -102,13 +106,25 @@ html_sidebars = {
 }
 
 # linkify_issues
-issue_url_tpl = f'{about["__github__"]}/issues/{{issue_id}}'
+issue_url_tpl = f"{about['__github__']}/issues/{{issue_id}}"
 
 # sphinx.ext.autodoc
 autoclass_content = "both"
 autodoc_member_order = "bysource"
+# Automatically extract typehints when specified and place them in
+# descriptions of the relevant function/method.
+autodoc_typehints = "description"
+# Don't show class signature with the class' name.
+autodoc_class_signature = "separated"
 toc_object_entries_show_parents = "hide"
 
+# sphinx-autodoc-typehints
+# Suppress warnings for forward references that can't be resolved
+# (types in TYPE_CHECKING blocks used for circular import avoidance)
+suppress_warnings = [
+    "sphinx_autodoc_typehints.forward_reference",
+]
+
 # sphinx-copybutton
 copybutton_prompt_text = (
     r">>> |\.\.\. |> |\$ |\# | In \[\d*\]: | {2,5}\.\.\.: | {5,8}: "
@@ -126,12 +142,12 @@ ogp_image = "_static/img/icons/icon-192x192.png"
 ogp_site_name = about["__title__"]
 
 intersphinx_mapping = {
-    "": ("https://docs.python.org/", None),
+    "python": ("https://docs.python.org/", None),
     "pytest": ("https://docs.pytest.org/en/stable/", None),
 }
 
 
-def linkcode_resolve(domain: str, info: t.Dict[str, str]) -> t.Union[None, str]:
+def linkcode_resolve(domain: str, info: dict[str, str]) -> None | str:
     """
     Determine the URL corresponding to Python object.
 
@@ -179,7 +195,7 @@ def linkcode_resolve(domain: str, info: t.Dict[str, str]) -> t.Union[None, str]:
     except Exception:
         lineno = None
 
-    linespec = "#L%d-L%d" % (lineno, lineno + len(source) - 1) if lineno else ""
+    linespec = f"#L{lineno}-L{lineno + len(source) - 1}" if lineno else ""
 
     fn = relpath(fn, start=pathlib.Path(libtmux.__file__).parent)
 
@@ -191,18 +207,17 @@ def linkcode_resolve(domain: str, info: t.Dict[str, str]) -> t.Union[None, str]:
             fn,
             linespec,
         )
-    else:
-        return "{}/blob/v{}/{}/{}/{}{}".format(
-            about["__github__"],
-            about["__version__"],
-            "src",
-            about["__package_name__"],
-            fn,
-            linespec,
-        )
+    return "{}/blob/v{}/{}/{}/{}{}".format(
+        about["__github__"],
+        about["__version__"],
+        "src",
+        about["__package_name__"],
+        fn,
+        linespec,
+    )
 
 
-def remove_tabs_js(app: "Sphinx", exc: Exception) -> None:
+def remove_tabs_js(app: Sphinx, exc: Exception) -> None:
     """Remove tabs.js from _static after build."""
     # Fix for sphinx-inline-tabs#18
     if app.builder.format == "html" and not exc:
@@ -211,6 +226,6 @@ def remove_tabs_js(app: "Sphinx", exc: Exception) -> None:
             tabs_js.unlink()  # When python 3.7 deprecated, use missing_ok=True
 
 
-def setup(app: "Sphinx") -> None:
+def setup(app: Sphinx) -> None:
     """Configure Sphinx app hooks."""
     app.connect("build-finished", remove_tabs_js)
